@@ -16,10 +16,10 @@
   #define CMARK_ATTRIBUTE(list)
 #endif
 
-#define HAVE_VA_COPY
-
-#ifndef HAVE_VA_COPY
-  #define va_copy(dest, src) ((dest) = (src))
+#ifndef CMARK_INLINE
+  #if defined(_MSC_VER) && !defined(__cplusplus)
+    #define CMARK_INLINE __inline
+  #else
+    #define CMARK_INLINE inline
+  #endif
 #endif
-
-#define HAVE_C99_SNPRINTF
